@@ -36,18 +36,18 @@ class Console::CommandDispatcher::Android
     }
 
     reqs = {
-      'dump_sms'         => ['dump_sms'],
-      'dump_contacts'    => ['dump_contacts'],
-      'geolocate'        => ['geolocate'],
-      'dump_calllog'     => ['dump_calllog'],
-      'check_root'       => ['check_root'],
-      'device_shutdown'  => ['device_shutdown'],
-      'send_sms'         => ['send_sms'],
-      'wlan_geolocate'   => ['wlan_geolocate'],
-      'interval_collect' => ['interval_collect'],
-      'activity_start'   => ['activity_start'],
-      'sqlite_query'     => ['sqlite_query'],
-      'set_audio_mode'   => ['set_audio_mode']
+      'dump_sms'         => ['android_dump_sms'],
+      'dump_contacts'    => ['android_dump_contacts'],
+      'geolocate'        => ['android_geolocate'],
+      'dump_calllog'     => ['android_dump_calllog'],
+      'check_root'       => ['android_check_root'],
+      'device_shutdown'  => ['android_device_shutdown'],
+      'send_sms'         => ['android_send_sms'],
+      'wlan_geolocate'   => ['android_wlan_geolocate'],
+      'interval_collect' => ['android_interval_collect'],
+      'activity_start'   => ['android_activity_start'],
+      'sqlite_query'     => ['android_sqlite_query'],
+      'set_audio_mode'   => ['android_set_audio_mode']
     }
 
     # Ensure any requirements of the command are met
